.. :changelog:

History
-------

0.1.4 (2017-03-22)
---------------------
* Fix issue #7, where an expired session is never renewed.
* Cleanup and make more Pythonic

0.1.3 (2016-02-19)
---------------------
* Implement authentication caching


0.1.2 (2016-01-07)
---------------------

* Fix issue passing strings to show and delete methods
* Add Python 3 compatibility

0.1.1 (2015-11-11)
---------------------

* Fix module naming issue

0.1.0 (2015-11-09)
---------------------

* First release on PyPI.
